package net.peachjean.slf4j.mojo;

import java.util.concurrent.Callable;
import java.util.concurrent.Executors;

import org.apache.maven.plugin.logging.Log;

public class CurrentMojoLogger
{
	private CurrentMojoLogger() {
		// do nothing
	}

	private static final ThreadLocal<Log> currentMavenLog = new ThreadLocal();

	static Log getCurrentMavenLog() {
		Log log = currentMavenLog.get();
		if(log == null) {
			throw new IllegalStateException("There is no current mojo log.  The mojo log is only available when "
			                                + "called from within a " + AbstractLoggingMojo.class.getSimpleName()
			                                + " or within a " + CurrentMojoLogger.class.getSimpleName());
		}
		return log;
	}

	public static void doWithLog(Log log, Runnable runnable) throws Exception
	{
		doWithLog(log, Executors.callable(runnable));
	}

	public static <T> T doWithLog(Log log, Callable<T> callable) throws Exception
	{
		try {
			currentMavenLog.set(log);
			return callable.call();
		} finally {
			currentMavenLog.remove();
		}
	}
}
